@@ -22,7 +22,6 @@ from ..utils.family_ops import restructure_list_to_exclude_certain_family_member
 from ..event_handler.event_type import EventType
 from ..event_handler import EVENT_DISPATCHER
 from ..logger import log
-from pyglet.window import key
 
 
 class Scene(object):
@@ -43,8 +42,11 @@ class Scene(object):
 
     def __init__(self, **kwargs):
         digest_config(self, kwargs)
+        print(self.preview)
         if self.preview:
+            global key, Window
             from ..window import Window
+            from pyglet.window import key
             self.window = Window(scene=self, **self.window_config)
             self.camera_config["ctx"] = self.window.ctx
             self.camera_config["frame_rate"] = 30  # Where's that 30 from?
