@@ -1,8 +1,8 @@
 import os
 import tempfile
 
-from manimlib.config import get_custom_config
-from manimlib.config import get_manim_dir
+from ..config import get_custom_config
+from ..config import get_manim_dir
 
 CUSTOMIZATION = {}
 
@@ -16,7 +16,7 @@ def get_customization():
         if not directories["temporary_storage"]:
             directories["temporary_storage"] = tempfile.gettempdir()
 
-        # Assumes all shaders are written into manimlib/shaders
+        # Assumes all shaders are written into ./shaders
         directories["shaders"] = os.path.join(
             get_manim_dir(), "manimlib", "shaders"
         )
